import { SQLConnection, SQLConnectionPool, SQLDatabaseAdapter, SQLDatabaseQuery, SQLDatabaseQueryFactory, SQLPersistence, SQLQueryModel, SQLQueryResolver, SQLStatement, DefaultPlatform } from '@deepkit/sql';
import { Changes, DatabasePersistenceChangeSet, DatabaseSession, DeleteResult, Entity, PatchResult } from '@deepkit/orm';
import { PostgresPlatform } from './postgres-platform';
import { ClassSchema } from '@deepkit/type';
import pg from 'pg';
import type { PoolClient, PoolConfig, Pool } from 'pg';
import { ClassType } from '@deepkit/core';
export declare class PostgresStatement extends SQLStatement {
    protected sql: string;
    protected client: PoolClient;
    protected released: boolean;
    constructor(sql: string, client: PoolClient);
    get(params?: any[]): Promise<any>;
    all(params?: any[]): Promise<any>;
    release(): void;
}
export declare class PostgresConnection extends SQLConnection {
    protected getConnection: () => Promise<PoolClient>;
    protected changes: number;
    lastReturningRows: any[];
    protected connection?: PoolClient;
    constructor(connectionPool: PostgresConnectionPool, getConnection: () => Promise<PoolClient>);
    release(): void;
    prepare(sql: string): Promise<PostgresStatement>;
    run(sql: string, params?: any[]): Promise<void>;
    getChanges(): Promise<number>;
}
export declare class PostgresConnectionPool extends SQLConnectionPool {
    protected pool: Pool;
    constructor(pool: Pool);
    getConnection(): PostgresConnection;
}
export declare class PostgresPersistence extends SQLPersistence {
    protected platform: DefaultPlatform;
    protected connection: PostgresConnection;
    constructor(platform: DefaultPlatform, connection: PostgresConnection);
    update<T extends Entity>(classSchema: ClassSchema<T>, changeSets: DatabasePersistenceChangeSet<T>[]): Promise<void>;
    protected populateAutoIncrementFields<T>(classSchema: ClassSchema<T>, items: T[]): Promise<void>;
    protected getInsertSQL(classSchema: ClassSchema, fields: string[], values: string[]): string;
    protected placeholderPosition: number;
    protected resetPlaceholderSymbol(): void;
    protected getPlaceholderSymbol(): string;
}
export declare class PostgresSQLQueryResolver<T extends Entity> extends SQLQueryResolver<T> {
    delete(model: SQLQueryModel<T>, deleteResult: DeleteResult<T>): Promise<void>;
    patch(model: SQLQueryModel<T>, changes: Changes<T>, patchResult: PatchResult<T>): Promise<void>;
}
export declare class PostgresSQLDatabaseQuery<T> extends SQLDatabaseQuery<T> {
}
export declare class PostgresSQLDatabaseQueryFactory extends SQLDatabaseQueryFactory {
    createQuery<T extends Entity>(classType: ClassType<T> | ClassSchema<T>): PostgresSQLDatabaseQuery<T>;
}
export declare class PostgresDatabaseAdapter extends SQLDatabaseAdapter {
    protected options: PoolConfig;
    protected pool: pg.Pool;
    connectionPool: PostgresConnectionPool;
    platform: PostgresPlatform;
    constructor(options: PoolConfig);
    getName(): string;
    getSchemaName(): string;
    createPersistence(): SQLPersistence;
    queryFactory(databaseSession: DatabaseSession<any>): SQLDatabaseQueryFactory;
    disconnect(force?: boolean): void;
}
